import eventlet
import eventlet.wsgi
import socketio
import threading


sio = socketio.Server(cors_allowed_origins='*')
app = socketio.WSGIApp(sio)


CONNECTIONS = []
QUEUE = []


@sio.event()
def connect(sid, environ, request):
    print('connect ', sid)
    CONNECTIONS.append(sid)


@sio.event
def my_message(sid, data):
    print('message ', data)
    sio.emit("message", {"data": "message"})


@sio.event
def disconnect(sid):
    if sid in CONNECTIONS:
        CONNECTIONS.remove(sid)


def send_message(msg="", event="message", to=None):
    return QUEUE.append(dict(
        msg=msg,
        event=event,
        sid=to
    ))


def handle_queue():
    while True:
        sio.sleep(0.01)
        while QUEUE:
            message = QUEUE.pop(0)
            sio.emit(message.get("event"), {"data": message.get("msg")}, to=message.get("sid"))


def run_wsgi(host="", port=5000):
    eventlet.wsgi.server(eventlet.listen((host, port)), app)


def start_server(host="", port=5000, threaded=True, cors=True, static_files=None):
    global sio, app
    if not cors:
        sio = socketio.Server()
    if static_files:
        app = socketio.WSGIApp(sio, static_files=static_files)
    sio.start_background_task(handle_queue)
    if not threaded:
        run_wsgi(host=host, port=port)
    threading.Thread(target=run_wsgi, args=(host, port, )).start()


start_server(threaded=False)





from setuptools import setup, find_packages


def read_requirements(file):
    with open(file) as f:
        return f.read().splitlines()


def read_file(file):
    with open(file) as f:
        return f.read()


long_description = read_file("README.md")
requirements = read_requirements("requirements.txt")

setup(
    name='easy-socketio',
    version='0.0.5',
    author='Tarik Gün (tarik56)',
    url='https://github.com/tarik56/easy-socketio',
    description='A simple wrapper around python-socketio that handles a simple que and threading.',
    long_description_content_type="text/x-rst",
    long_description=long_description,
    license="MIT license",
    packages=['easy_socketio'],
    package_dir={'':'src'},
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
